@@ -14,7 +14,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.82';    # VERSION
+our $VERSION = '3.84';    # VERSION
 my @OPTIONS_ATTRIBUTES
     = qw/format short repeatable negativable autosplit doc order json/;
 
@@ -162,7 +162,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.82
+version 3.84
 
 =head1 MooX::Options
 
@@ -415,7 +415,7 @@ Ex:
 
 =item autosplit
 
-auto split args to generate multiple value. It implie "repeatable".
+auto split args to generate multiple value. It implies "repeatable".
 autosplit take the separator value, ex: ",".
 
 Ex :
@@ -432,7 +432,7 @@ Ex :
 
     local @ARGV=('--test=1,2,3,4');
     my $t = t->new_with_options;
-    t->test # [1,2,3,4]
+    $t->test; # [1,2,3,4]
 
 I automatically take the quoted as a group separator value
 
@@ -446,7 +446,7 @@ I automatically take the quoted as a group separator value
 
     local @ARGV=('--test=a,b,"c,d",e');
     my $t = str->new_with_options;
-    t->test # ['a','b','c,d','e']
+    $t->test; # ['a','b','c,d','e']
 
 =item short
 
@@ -465,7 +465,7 @@ Ex :
     }
     local @ARGV=('-vvv');
     my $t = t->new_with_options;
-    t->verbose # 3
+    $t->verbose; # 3
 
 =item order
 
@@ -490,7 +490,7 @@ Ex :
     }
     local @ARGV=('--hash', '{"a":1,"b":2}');
     my $t = t->new_with_options;
-    t->hash # { a => 1, b => 2 }
+    $t->hash; # { a => 1, b => 2 }
 
 =back
 
